@@ -6,7 +6,7 @@ no warnings qw(void once uninitialized numeric);
 package PerlX::Assert;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.030';
+our $VERSION   = '0.031';
 
 use Keyword::Simple ();
 
@@ -57,7 +57,7 @@ sub import
 		}
 		else
 		{
-			substr($$ref, 0, 0) = "0 and $do";
+			substr($$ref, 0, 0) = "() and $do";
 		}
 	});
 }
